vortex\_criterions module
========================================================

.. automodule:: IMTreatment.vortex_criterions.vortex_criterions
    :members:
    :undoc-members:
    :show-inheritance:
